pub struct ChickenEntity {
base: EntityBase,
entity_type: EntityTypeRef,
living_base: LivingEntityBase,
mob_base: MobBase,
ageable_base: AgeableMobBase,
animal_base: AnimalBase,
chicken_state: SyncMutex<ChickenState>,
entity_data: SyncMutex<ChickenEntityData>,
}Expand description
Vanilla chicken entity.
Fields
base: EntityBaseentity_type: EntityTypeRefliving_base: LivingEntityBasemob_base: MobBaseageable_base: AgeableMobBaseanimal_base: AnimalBasechicken_state: SyncMutex<ChickenState>entity_data: SyncMutex<ChickenEntityData>Implementations
Sourceimpl ChickenEntity
impl ChickenEntity
Sourcepub fn new(
entity_type: EntityTypeRef,
id: i32,
position: DVec3,
world: Weak<World>,
) -> Self
pub fn new( entity_type: EntityTypeRef, id: i32, position: DVec3, world: Weak<World>, ) -> Self
Creates a new chicken at runtime.
Sourcepub fn from_saved(entity_type: EntityTypeRef, load: EntityBaseLoad) -> Self
pub fn from_saved(entity_type: EntityTypeRef, load: EntityBaseLoad) -> Self
Reconstructs a chicken from persisted base entity state.
fn new_with_base(base: EntityBase, entity_type: EntityTypeRef) -> Self
Sourcepub fn set_variant(&self, variant: ChickenVariantRef)
pub fn set_variant(&self, variant: ChickenVariantRef)
Sets the active chicken variant by registry entry.
Sourcepub fn variant(&self) -> ChickenVariantRef
pub fn variant(&self) -> ChickenVariantRef
Returns the active chicken variant, falling back to temperate when invalid.
Sourcepub fn set_sound_variant(&self, sound_variant: ChickenSoundVariantRef)
pub fn set_sound_variant(&self, sound_variant: ChickenSoundVariantRef)
Sets the active chicken sound variant by registry entry.
Sourcepub fn sound_variant(&self) -> ChickenSoundVariantRef
pub fn sound_variant(&self) -> ChickenSoundVariantRef
Returns the active chicken sound variant, falling back to classic when invalid.
fn set_variant_by_key(&self, key: &Identifier) -> bool
fn set_sound_variant_by_key(&self, key: &Identifier)
Sourcefn current_sound_set(&self) -> &'static ChickenAge
fn current_sound_set(&self) -> &'static ChickenAge
Returns the sound set for this chicken’s current age (vanilla Chicken.getSoundSet).
fn update_dirty_mob_effect_entity_data(&self)
Sourcepub fn is_food(item_stack: &ItemStack) -> bool
pub fn is_food(item_stack: &ItemStack) -> bool
Returns whether an item stack matches the vanilla chicken food tag.
Sourcepub fn is_chicken_jockey(&self) -> bool
pub fn is_chicken_jockey(&self) -> bool
Returns vanilla Chicken.isChickenJockey.
Sourcepub fn set_chicken_jockey(&self, is_chicken_jockey: bool)
pub fn set_chicken_jockey(&self, is_chicken_jockey: bool)
Sets vanilla Chicken.isChickenJockey.
Sourcefn set_egg_time(&self, egg_time: i32)
fn set_egg_time(&self, egg_time: i32)
Sets the remaining ticks before the next egg is laid.
Sourcefn roll_egg_lay_time() -> i32
fn roll_egg_lay_time() -> i32
Rolls the vanilla randomized delay before the next egg lay.
Sourcefn tick_flapping(&self)
fn tick_flapping(&self)
Runs vanilla Chicken.aiStep wing-flap and slow-fall side effects.
Sourcefn tick_egg_laying(&self)
fn tick_egg_laying(&self)
Runs vanilla Chicken.aiStep egg-laying side effects.
Sourcefn drop_gift_loot_table(&self, loot_table: LootTableRef) -> bool
fn drop_gift_loot_table(&self, loot_table: LootTableRef) -> bool
Rolls a gift loot table at this entity’s position and drops each result.
Mirrors vanilla LivingEntity.dropFromGiftLootTable for the
gameplay/chicken_lay table, returning whether any item was dropped.